@@ -154,7 +154,7 @@ def get_stats(arr, n = 5):
     ticks = [min_ + i * interval for i in range(n)]
     return ticks
 
-def map2darr(arr, uniqueLons, uniqueLats, unit = "", cmap = "viridis", figsize = [6, 4]):
+def map2darr(arr, uniqueLons, uniqueLats, unit = "", cmap = "viridis", figsize = [6, 4], vmin = None, vmax = None):
     ticklabels = [latex_float(f) for f in get_stats(arr)]
 
     arr = 255 * (arr - np.nanmin(arr)) / (np.nanmax(arr) - np.nanmin(arr))
@@ -164,7 +164,7 @@ def map2darr(arr, uniqueLons, uniqueLats, unit = "", cmap = "viridis", figsize =
     fig, ax = plt.subplots(figsize = figsize)
     divider = make_axes_locatable(ax)
     cax = divider.append_axes('right', size='5%', pad=0.05)
-    im = ax.imshow(arr, cmap = cmap, extent = [uniqueLons.min(), uniqueLons.max(), uniqueLats.min(), uniqueLats.max()])
+    im = ax.imshow(arr, cmap = cmap, extent = [uniqueLons.min(), uniqueLons.max(), uniqueLats.min(), uniqueLats.max()], vmin = vmin, vmax = vmax)
     # Add colorbar, make sure to specify tick locations to match desired ticklabels
     cbar = fig.colorbar(im, cax = cax, orientation = 'vertical', ticks = ticks)
     cbar.ax.set_yticklabels(ticklabels)  # vertically oriented colorbar
@@ -199,7 +199,7 @@ class VegIdx:
 
     # EVI
     # --------------------------------------------------------------------------------------------------------------
-    # EVI = G * ((NIR - R) / (NIR + C1 * R – C2 * B + L))
+    # EVI = G * ((NIR - R) / (NIR + C1 * R - C2 * B + L))
     @staticmethod
     def modis_evi_2band(b1, b2):
         return 2.5 * ((b2 - b1) / (b2 + 2.4 * b1 + 1))
@@ -210,12 +210,12 @@ class VegIdx:
 
     @staticmethod
     def landsat7_evi(b1, b3, b4):
-        return 2.5 * ((b4 – b3) / (b4 + 6 * b3 – 7.5 * b1 + 1))
+        return 2.5 * ((b4 - b3) / (b4 + 6 * b3 - 7.5 * b1 + 1))
 
     @staticmethod
     def landsat8_evi(b2, b4, b5):
-        return 2.5 * ((b5 – b4) / (b5 + 6 * b4 – 7.5 * b2 + 1))
+        return 2.5 * ((b5 - b4) / (b5 + 6 * b4 - 7.5 * b2 + 1))
 
     @staticmethod
     def sentinel2_evi(b2, b4, b8):
-        return 2.5 * ((b8 – b4) / (b8 + 6 * b4 – 7.5 * b2 + 1))
\ No newline at end of file
+        return 2.5 * ((b8 - b4) / (b8 + 6 * b4 - 7.5 * b2 + 1))
\ No newline at end of file
